==> nextcloud-app-news-14.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/fa.js <==
OC.L10N.register(
    "news",
    {
    "Can not add feed: Exists already" : "خوراک خوان را نمی تواند اضافه کند: در حال حاضر موجود است.",
    "Can not add folder: Exists already" : "پوشه را نمی تواند اضافه کند: در حال حاضر وجود دارد.",
    "Saved" : "ذخیره شد",
    "Download" : "دانلود",
    "Close" : "بستن",
    "Language" : "زبان",
    "Subscribe" : "اشتراک گذاری",
    "No articles available" : "هیچ مقاله‌ای موجود نیست",
    "No unread articles available" : "هیچ مقاله‌ی خوانده‌ نشده‌ای موجود نیست",
    "Open website" : "باز کردن وب‌سایت",
    "by" : "با",
    "from" : "از",
    "Play audio" : "پخش صوت",
    "Download audio" : "دانلود صوت",
    "Download video" : "دانلود ویدئو",
    "Description" : "توضیحات",
    "right" : "راست",
    "left" : "چپ",
    "Open article in new tab" : "باز کردن مقاله در تب جدید",
    "Refresh" : "بازنمایی",
    "Web address" : "آدرس وب",
    "Folder" : "پوشه",
    "No folder" : "بدون پوشه",
    "New folder" : "پوشه جدید",
    "Folder name" : "نام پوشه",
    "Folder exists already!" : "پوشه در حال حاضر موجود است!",
    "Credentials" : "اعتبارهای",
    "Username" : "نام کاربری",
    "Password" : "گذرواژه",
    "New Folder" : "پوشه جدید",
    "Create" : "ایجاد کردن",
    "Rename" : "تغییرنام",
    "Menu" : "منو",
    "Newest first" : "تازه ترین ها اول ",
    "Oldest first" : "قدیمی ترین ها اول ",
    "Delete" : "حذف",
    "Dismiss" : "پنهان کن",
    "Collapse" : "فروکش  کردن",
    "Deleted folder" : "پوشه‌ی حذف شده",
    "Starred" : "ستاره دار",
    "Unread articles" : "مطالب خوانده نشده",
    "All articles" : "تمام مطالب",
    "Settings" : "تنظیمات",
    "Compact view" : "نمایش متراکم",
    "Show all articles" : "نمایش تمامی مقالات",
    "Subscriptions (OPML)" : "اشتراک‌ها (OPML)",
    "Import" : "وارد کردن",
    "Export" : "گرفتن خروجی",
    "Error when importing: file does not contain valid JSON" : "خطا هنگام وارد کردن: فایل حاوی JSON معتبر نیست.",
    "Help" : "کمک",
    "Keyboard shortcuts" : "میان بر صفحه ی کلید",
    "Documentation" : "مستندسازی"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-news-14.1.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/fa.js <==
OC.L10N.register(
    "news",
    {
    "Can not add feed: Exists already" : "خوراک خوان را نمی تواند اضافه کند: در حال حاضر موجود است.",
    "Can not add folder: Exists already" : "پوشه را نمی تواند اضافه کند: در حال حاضر وجود دارد.",
    "Saved" : "ذخیره شد",
    "Download" : "دانلود",
    "Close" : "بستن",
    "Language" : "زبان",
    "Subscribe" : "اشتراک گذاری",
    "No articles available" : "هیچ مقاله‌ای موجود نیست",
    "No unread articles available" : "هیچ مقاله‌ی خوانده‌ نشده‌ای موجود نیست",
    "Open website" : "باز کردن وب‌سایت",
    "by" : "با",
    "from" : "از",
    "Play audio" : "پخش صوت",
    "Download audio" : "دانلود صوت",
    "Download video" : "دانلود ویدئو",
    "Description" : "توضیحات",
    "right" : "راست",
    "left" : "چپ",
    "Open article in new tab" : "باز کردن مقاله در تب جدید",
    "Refresh" : "بازنمایی",
    "Web address" : "آدرس وب",
    "Folder" : "پوشه",
    "No folder" : "بدون پوشه",
    "New folder" : "پوشه جدید",
    "Folder name" : "نام پوشه",
    "Folder exists already!" : "پوشه در حال حاضر موجود است!",
    "Credentials" : "اعتبارهای",
    "Username" : "نام کاربری",
    "Password" : "گذرواژه",
    "New Folder" : "پوشه جدید",
    "Create" : "ایجاد کردن",
    "Rename" : "تغییرنام",
    "Menu" : "منو",
    "Newest first" : "تازه ترین ها اول ",
    "Oldest first" : "قدیمی ترین ها اول ",
    "Delete" : "حذف",
    "Dismiss" : "پنهان کن",
    "Collapse" : "فروکش  کردن",
    "Deleted folder" : "پوشه‌ی حذف شده",
    "Starred" : "ستاره دار",
    "Unread articles" : "مطالب خوانده نشده",
    "All articles" : "تمام مطالب",
    "Settings" : "تنظیمات",
    "Compact view" : "نمایش متراکم",
    "Show all articles" : "نمایش تمامی مقالات",
    "Subscriptions (OPML)" : "اشتراک‌ها (OPML)",
    "Import" : "وارد کردن",
    "Export" : "گرفتن خروجی",
    "Error when importing: file does not contain valid JSON" : "خطا هنگام وارد کردن: فایل حاوی JSON معتبر نیست.",
    "Help" : "کمک",
    "Keyboard shortcuts" : "میان بر صفحه ی کلید",
    "Documentation" : "مستندسازی",
    "Report a bug" : "گزارش یک خطا"
},
"nplurals=2; plural=(n > 1);");
